@@ -787,7 +787,7 @@ class Import_session(object):
     #===========================================================================
     # Inline actions
     #===========================================================================
-    def _skip_line(self, line, data, model, type_='skip'):
+    def _skip(self, line, data, model, type_="skip"):
         """Raise an SkipLineException if 'SKIP' is found in data keys
         and if callback returns True
 
@@ -806,11 +806,11 @@ class Import_session(object):
                     returned_value = self._get_callback(line, model, callback,
                             key, content)
                     if returned_value is compare_value:
-                        raise exceptions.SkipLineException('%s is required' % key.split('::')[1])
-                    else:
-                        # rename key becomed unusefull
-                        data[key.split('::')[1]] = data[key]
-                        del data[key]
+                        raise exceptions.SkipObjectException('%s is required' % key.split('::')[1])
+                    
+                    # rename key becomed unusefull
+                    data[key.split('::')[1]] = data[key]
+                    del data[key]
                     self._logger.debug('<%-25s> processing %s=%s' % (model, key,
                         returned_value), extra=STATS[self._id])
                 else:
@@ -1311,8 +1311,8 @@ formed, \n\n" % (model, attr)
 
         # Exceptions if any
         #=======================================================================
-        self._skip_line(line, data, model, type_='skip')
-        self._skip_line(line, data, model, type_='required')
+        self._skip(line, data, model, type_='skip')
+        self._skip(line, data, model, type_='required')
         self._ignore_object(line, data, model)
         self._replace_line(line, data, model) 
         self._route_line(line, data, model) 
