@@ -435,6 +435,23 @@ def zfill(*args, **kwargs):
 
     return _zfill
 
+def lower(*args, **kwargs):
+    """Return a uppered string.
+
+    .. note::
+        
+        This function is a rewriting of string.lower, same signature
+
+    >>> 'address': Column(3, lower())
+    
+    :returns: callback_model
+    
+    """
+    def _upper(self, model ,field, value, line):
+        return value.lower(*args, **kwargs)
+
+    return _upper
+
 def upper(*args, **kwargs):
     """Return a uppered string.
 
